@@ -1,6 +1,7 @@
 //! Language enumerations
 use std::{fmt::Display, str::FromStr};
 
+use log::warn;
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
@@ -404,6 +405,10 @@ impl FromStr for Lang {
             "bxr" => Ok(Self::Bxr),
             "ca" => Ok(Self::Ca),
             "cbk" => Ok(Self::Cbk),
+            "cbr" => {
+                warn!("cbr detected! branching to cbk. More info here: https://github.com/oscar-corpus/ungoliant/issues/53");
+                Ok(Self::Cbk)
+            }
             "ce" => Ok(Self::Ce),
             "ceb" => Ok(Self::Ceb),
             "ckb" => Ok(Self::Ckb),
@@ -583,4 +588,13 @@ mod tests {
         let cbk_string = "cbk";
         assert_eq!(Lang::from_str(cbk_string).unwrap(), Lang::Cbk);
     }
+
+    #[test]
+    fn test_cbr() {
+        let cbk_language = Lang::Cbk;
+        assert_eq!(&cbk_language.to_string(), "cbk");
+
+        let cbk_string = "cbr";
+        assert_eq!(Lang::from_str(cbk_string).unwrap(), Lang::Cbk);
+    }
 }
